<?php

namespace ZeroBounce\SDK;

use ReflectionClass;

abstract class BasicEnum {
    private static $constCacheArray = NULL;

    private function __construct(){
        /*
          Preventing instance :)
        */
    }

    private static function getConstants() {
        if (self::$constCacheArray == NULL) {
            self::$constCacheArray = [];
        }
        $calledClass = get_called_class();
        if (!array_key_exists($calledClass, self::$constCacheArray)) {
            $reflect = new ReflectionClass($calledClass);
            self::$constCacheArray[$calledClass] = $reflect->getConstants();
        }
        return self::$constCacheArray[$calledClass];
    }

    public static function isValidName($name, $strict = false) {
        $constants = self::getConstants();

        if ($strict) {
            return array_key_exists($name, $constants);
        }

        $keys = array_map('strtolower', array_keys($constants));
        return in_array(strtolower($name), $keys);
    }

    public static function isValidValue($value) {
        $values = array_values(self::getConstants());
        return in_array($value, $values, $strict = true);
    }

    public static function getByValue($value) {
        $values = array_values(self::getConstants());
        if(in_array($value, $values, $strict = true)) return $value;
        return NULL;
    }
}